import Vue from 'vue';
import Router from 'vue-router';
import { AuthGuard } from '@/utils';
import qs from 'qs';

Vue.use(Router);

const router = new Router({
    routes: [
        {
            path: '/index/:index?',
            beforeEnter: (to: any, from: any, next: any) => {
                const routerParamsName = 'index';
                const params: any = {};
                if (to.params && to.params[routerParamsName]) {
                    Object.assign(params, qs.parse(to.params[routerParamsName], { delimiter: ';' }));
                }
                const url: string = '/appdata';
                const auth: Promise<any> = AuthGuard.getInstance().authGuard(url, params, router);
                auth.then(() => {
                    next();
                }).catch(() => {
                    next();
                });
            },
            meta: {  
                caption: '运行管控系统',
                viewType: 'APPINDEX',
                parameters: [
                    { pathName: 'index', parameterName: 'index' },
                ],
                requireAuth: true,
            },
            component: () => import('@pages/ungroup/index/index.vue'),
            children: [
                {
                    path: 'orgusers/:orguser?/pickupview/:pickupview?',
                    meta: {
                        caption: 'orguser.views.pickupview.caption',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'orgusers', parameterName: 'orguser' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/org/org-user-pickup-view/org-user-pickup-view.vue'),
                },
                {
                    path: 'orgs/:org?/pickupview/:pickupview?',
                    meta: {
                        caption: 'org.views.pickupview.caption',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'orgs', parameterName: 'org' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/org/org-pickup-view/org-pickup-view.vue'),
                },
                {
                    path: 'userroles/:userrole?/editview3/:editview3?',
                    meta: {
                        caption: 'userrole.views.editview3.caption',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'userroles', parameterName: 'userrole' },
                            { pathName: 'editview3', parameterName: 'editview3' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/privilege/user-role-edit-view3/user-role-edit-view3.vue'),
                },
                {
                    path: 'userobjects/:userobject?/editview/:editview?',
                    meta: {
                        caption: 'userobject.views.editview.caption',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'userobjects', parameterName: 'userobject' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/privilege/user-object-edit-view/user-object-edit-view.vue'),
                },
                {
                    path: 'orgusers/:orguser?/editview3/:editview3?',
                    meta: {
                        caption: 'orguser.views.editview3.caption',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'orgusers', parameterName: 'orguser' },
                            { pathName: 'editview3', parameterName: 'editview3' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/org/org-user-edit-view3/org-user-edit-view3.vue'),
                },
                {
                    path: 'dataentities/:dataentity?/editview/:editview?',
                    meta: {
                        caption: 'dataentity.views.editview.caption',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'dataentities', parameterName: 'dataentity' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/privilege/data-entity-edit-view/data-entity-edit-view.vue'),
                },
                {
                    path: 'usergroups/:usergroup?/mpickupview/:mpickupview?',
                    meta: {
                        caption: 'usergroup.views.mpickupview.caption',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'usergroups', parameterName: 'usergroup' },
                            { pathName: 'mpickupview', parameterName: 'mpickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/privilege/user-group-mpickup-view/user-group-mpickup-view.vue'),
                },
                {
                    path: 'userroledata/:userroledata?/pickupview/:pickupview?',
                    meta: {
                        caption: 'userroledata.views.pickupview.caption',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'userroledata', parameterName: 'userroledata' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/privilege/user-role-data-pickup-view/user-role-data-pickup-view.vue'),
                },
                {
                    path: 'userroledata/:userroledata?/mpickupview/:mpickupview?',
                    meta: {
                        caption: 'userroledata.views.mpickupview.caption',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'userroledata', parameterName: 'userroledata' },
                            { pathName: 'mpickupview', parameterName: 'mpickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/privilege/user-role-data-mpickup-view/user-role-data-mpickup-view.vue'),
                },
                {
                    path: 'userroles/:userrole?/usrcreateeditview3/:usrcreateeditview3?',
                    meta: {
                        caption: 'userrole.views.usrcreateeditview3.caption',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'userroles', parameterName: 'userrole' },
                            { pathName: 'usrcreateeditview3', parameterName: 'usrcreateeditview3' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/privilege/user-role-usr-create-edit-view3/user-role-usr-create-edit-view3.vue'),
                },
                {
                    path: 'userroleres/:userroleres?/gridview/:gridview?',
                    meta: {
                        caption: 'userroleres.views.gridview.caption',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'userroleres', parameterName: 'userroleres' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/privilege/user-role-res-grid-view/user-role-res-grid-view.vue'),
                },
                {
                    path: 'userroledatas/:userroledatas?/gridview/:gridview?',
                    meta: {
                        caption: 'userroledatas.views.gridview.caption',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'userroledatas', parameterName: 'userroledatas' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/privilege/userroledatasgrid-view/userroledatasgrid-view.vue'),
                },
                {
                    path: 'userroledata/:userroledata?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'userroledata.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'userroledata', parameterName: 'userroledata' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/privilege/user-role-data-pickup-grid-view/user-role-data-pickup-grid-view.vue'),
                },
                {
                    path: 'users/:user?/pickupview/:pickupview?',
                    meta: {
                        caption: 'user.views.pickupview.caption',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'users', parameterName: 'user' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/org/user-pickup-view/user-pickup-view.vue'),
                },
                {
                    path: 'userroledataactions/:userroledataaction?/gridview/:gridview?',
                    meta: {
                        caption: 'userroledataaction.views.gridview.caption',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'userroledataactions', parameterName: 'userroledataaction' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/privilege/user-role-data-action-grid-view/user-role-data-action-grid-view.vue'),
                },
                {
                    path: 'users/:user?/gridview/:gridview?',
                    meta: {
                        caption: 'user.views.gridview.caption',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'users', parameterName: 'user' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/org/user-grid-view/user-grid-view.vue'),
                },
                {
                    path: 'orgdepts/:orgdept?/editview/:editview?',
                    meta: {
                        caption: 'orgdept.views.editview.caption',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'orgdepts', parameterName: 'orgdept' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/org/org-dept-edit-view/org-dept-edit-view.vue'),
                },
                {
                    path: 'userobjects/:userobject?/pickupview/:pickupview?',
                    meta: {
                        caption: 'userobject.views.pickupview.caption',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'userobjects', parameterName: 'userobject' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/privilege/user-object-pickup-view/user-object-pickup-view.vue'),
                },
                {
                    path: 'usergroups/:usergroup?/editview/:editview?',
                    meta: {
                        caption: 'usergroup.views.editview.caption',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'usergroups', parameterName: 'usergroup' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/privilege/user-group-edit-view/user-group-edit-view.vue'),
                },
                {
                    path: 'users/:user?/editview/:editview?',
                    meta: {
                        caption: 'user.views.editview.caption',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'users', parameterName: 'user' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/org/user-edit-view/user-edit-view.vue'),
                },
                {
                    path: 'unires/:unires?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'unires.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'unires', parameterName: 'unires' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/privilege/uni-res-pickup-grid-view/uni-res-pickup-grid-view.vue'),
                },
                {
                    path: 'applications/:application?/gridview/:gridview?',
                    meta: {
                        caption: 'application.views.gridview.caption',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'applications', parameterName: 'application' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/privilege/application-grid-view/application-grid-view.vue'),
                },
                {
                    path: 'orgs/:org?/editview/:editview?',
                    meta: {
                        caption: 'org.views.editview.caption',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'orgs', parameterName: 'org' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/org/org-edit-view/org-edit-view.vue'),
                },
                {
                    path: 'unires/:unires?/editview/:editview?',
                    meta: {
                        caption: 'unires.views.editview.caption',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'unires', parameterName: 'unires' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/privilege/uni-res-edit-view/uni-res-edit-view.vue'),
                },
                {
                    path: 'orgdepts/:orgdept?/gridview/:gridview?',
                    meta: {
                        caption: 'orgdept.views.gridview.caption',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'orgdepts', parameterName: 'orgdept' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/org/org-dept-grid-view/org-dept-grid-view.vue'),
                },
                {
                    path: 'userroledataactions/:userroledataaction?/editview/:editview?',
                    meta: {
                        caption: 'userroledataaction.views.editview.caption',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'userroledataactions', parameterName: 'userroledataaction' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/privilege/user-role-data-action-edit-view/user-role-data-action-edit-view.vue'),
                },
                {
                    path: 'userroles/:userrole?/mpickupview/:mpickupview?',
                    meta: {
                        caption: 'userrole.views.mpickupview.caption',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'userroles', parameterName: 'userrole' },
                            { pathName: 'mpickupview', parameterName: 'mpickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/privilege/user-role-mpickup-view/user-role-mpickup-view.vue'),
                },
                {
                    path: 'unires/:unires?/gridview/:gridview?',
                    meta: {
                        caption: 'unires.views.gridview.caption',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'unires', parameterName: 'unires' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/privilege/uni-res-grid-view/uni-res-grid-view.vue'),
                },
                {
                    path: 'userroledetails/:userroledetail?/gridview/:gridview?',
                    meta: {
                        caption: 'userroledetail.views.gridview.caption',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'userroledetails', parameterName: 'userroledetail' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/privilege/user-role-detail-grid-view/user-role-detail-grid-view.vue'),
                },
                {
                    path: 'userobjects/:userobject?/gridview/:gridview?',
                    meta: {
                        caption: 'userobject.views.gridview.caption',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'userobjects', parameterName: 'userobject' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/privilege/user-object-grid-view/user-object-grid-view.vue'),
                },
                {
                    path: 'usergroups/:usergroup?/gridview/:gridview?',
                    meta: {
                        caption: 'usergroup.views.gridview.caption',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'usergroups', parameterName: 'usergroup' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/privilege/user-group-grid-view/user-group-grid-view.vue'),
                },
                {
                    path: 'usergroupdetails/:usergroupdetail?/gridview/:gridview?',
                    meta: {
                        caption: 'usergroupdetail.views.gridview.caption',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'usergroupdetails', parameterName: 'usergroupdetail' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/privilege/user-group-detail-grid-view/user-group-detail-grid-view.vue'),
                },
                {
                    path: 'dataentities/:dataentity?/gridview/:gridview?',
                    meta: {
                        caption: 'dataentity.views.gridview.caption',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'dataentities', parameterName: 'dataentity' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/privilege/data-entity-grid-view/data-entity-grid-view.vue'),
                },
                {
                    path: 'users/:user?/loginaccounts/:loginaccount?/gridview/:gridview?',
                    meta: {
                        caption: 'loginaccount.views.gridview.caption',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'users', parameterName: 'user' },
                            { pathName: 'loginaccounts', parameterName: 'loginaccount' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/org/login-account-grid-view/login-account-grid-view.vue'),
                },
                {
                    path: 'loginaccounts/:loginaccount?/gridview/:gridview?',
                    meta: {
                        caption: 'loginaccount.views.gridview.caption',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'loginaccounts', parameterName: 'loginaccount' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/org/login-account-grid-view/login-account-grid-view.vue'),
                },
                {
                    path: 'usergroups/:usergroup?/editview3/:editview3?',
                    meta: {
                        caption: 'usergroup.views.editview3.caption',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'usergroups', parameterName: 'usergroup' },
                            { pathName: 'editview3', parameterName: 'editview3' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/privilege/user-group-edit-view3/user-group-edit-view3.vue'),
                },
                {
                    path: 'unires/:unires?/pickupview/:pickupview?',
                    meta: {
                        caption: 'unires.views.pickupview.caption',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'unires', parameterName: 'unires' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/privilege/uni-res-pickup-view/uni-res-pickup-view.vue'),
                },
                {
                    path: 'orgs/:org?/gridview/:gridview?',
                    meta: {
                        caption: 'org.views.gridview.caption',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'orgs', parameterName: 'org' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/org/org-grid-view/org-grid-view.vue'),
                },
                {
                    path: 'usergroups/:usergroup?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'usergroup.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'usergroups', parameterName: 'usergroup' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/privilege/user-group-pickup-grid-view/user-group-pickup-grid-view.vue'),
                },
                {
                    path: 'systems/:system?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'system.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'systems', parameterName: 'system' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/privilege/system-pickup-grid-view/system-pickup-grid-view.vue'),
                },
                {
                    path: 'userroletypes/:userroletype?/editview/:editview?',
                    meta: {
                        caption: 'userroletype.views.editview.caption',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'userroletypes', parameterName: 'userroletype' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/privilege/user-role-type-edit-view/user-role-type-edit-view.vue'),
                },
                {
                    path: 'orgdeptusers/:orgdeptuser?/gridview/:gridview?',
                    meta: {
                        caption: 'orgdeptuser.views.gridview.caption',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'orgdeptusers', parameterName: 'orgdeptuser' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/org/org-dept-user-grid-view/org-dept-user-grid-view.vue'),
                },
                {
                    path: 'systems/:system?/gridview/:gridview?',
                    meta: {
                        caption: 'system.views.gridview.caption',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'systems', parameterName: 'system' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/privilege/system-grid-view/system-grid-view.vue'),
                },
                {
                    path: 'applications/:application?/editview/:editview?',
                    meta: {
                        caption: 'application.views.editview.caption',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'applications', parameterName: 'application' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/privilege/application-edit-view/application-edit-view.vue'),
                },
                {
                    path: 'userroledata/:userroledata?/editview3/:editview3?',
                    meta: {
                        caption: 'userroledata.views.editview3.caption',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'userroledata', parameterName: 'userroledata' },
                            { pathName: 'editview3', parameterName: 'editview3' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/privilege/user-role-data-edit-view3/user-role-data-edit-view3.vue'),
                },
                {
                    path: 'orgusers/:orguser?/gridview/:gridview?',
                    meta: {
                        caption: 'orguser.views.gridview.caption',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'orgusers', parameterName: 'orguser' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/org/org-user-grid-view/org-user-grid-view.vue'),
                },
                {
                    path: 'orgdeptusers/:orgdeptuser?/editview/:editview?',
                    meta: {
                        caption: 'orgdeptuser.views.editview.caption',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'orgdeptusers', parameterName: 'orgdeptuser' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/org/org-dept-user-edit-view/org-dept-user-edit-view.vue'),
                },
                {
                    path: 'userroles/:userrole?/pickupview/:pickupview?',
                    meta: {
                        caption: 'userrole.views.pickupview.caption',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'userroles', parameterName: 'userrole' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/privilege/user-role-pickup-view/user-role-pickup-view.vue'),
                },
                {
                    path: 'userroledetails/:userroledetail?/editview/:editview?',
                    meta: {
                        caption: 'userroledetail.views.editview.caption',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'userroledetails', parameterName: 'userroledetail' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/privilege/user-role-detail-edit-view/user-role-detail-edit-view.vue'),
                },
                {
                    path: 'userroledatas/:userroledatas?/editview/:editview?',
                    meta: {
                        caption: 'userroledatas.views.editview.caption',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'userroledatas', parameterName: 'userroledatas' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/privilege/userroledatasedit-view/userroledatasedit-view.vue'),
                },
                {
                    path: 'usergroupdetails/:usergroupdetail?/editview/:editview?',
                    meta: {
                        caption: 'usergroupdetail.views.editview.caption',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'usergroupdetails', parameterName: 'usergroupdetail' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/privilege/user-group-detail-edit-view/user-group-detail-edit-view.vue'),
                },
                {
                    path: 'dataentities/:dataentity?/pickupview/:pickupview?',
                    meta: {
                        caption: 'dataentity.views.pickupview.caption',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'dataentities', parameterName: 'dataentity' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/privilege/data-entity-pickup-view/data-entity-pickup-view.vue'),
                },
                {
                    path: 'dataentities/:dataentity?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'dataentity.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'dataentities', parameterName: 'dataentity' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/privilege/data-entity-pickup-grid-view/data-entity-pickup-grid-view.vue'),
                },
                {
                    path: 'userroleres/:userroleres?/editview/:editview?',
                    meta: {
                        caption: 'userroleres.views.editview.caption',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'userroleres', parameterName: 'userroleres' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/privilege/user-role-res-edit-view/user-role-res-edit-view.vue'),
                },
                {
                    path: 'orgs/:org?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'org.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'orgs', parameterName: 'org' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/org/org-pickup-grid-view/org-pickup-grid-view.vue'),
                },
                {
                    path: 'orgdepts/:orgdept?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'orgdept.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'orgdepts', parameterName: 'orgdept' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/org/org-dept-pickup-grid-view/org-dept-pickup-grid-view.vue'),
                },
                {
                    path: 'systems/:system?/editview/:editview?',
                    meta: {
                        caption: 'system.views.editview.caption',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'systems', parameterName: 'system' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/privilege/system-edit-view/system-edit-view.vue'),
                },
                {
                    path: 'unires/:unires?/mpickupview/:mpickupview?',
                    meta: {
                        caption: 'unires.views.mpickupview.caption',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'unires', parameterName: 'unires' },
                            { pathName: 'mpickupview', parameterName: 'mpickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/privilege/uni-res-mpickup-view/uni-res-mpickup-view.vue'),
                },
                {
                    path: 'userroles/:userrole?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'userrole.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'userroles', parameterName: 'userrole' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/privilege/user-role-pickup-grid-view/user-role-pickup-grid-view.vue'),
                },
                {
                    path: 'userroledata/:userroledata?/gridview/:gridview?',
                    meta: {
                        caption: 'userroledata.views.gridview.caption',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'userroledata', parameterName: 'userroledata' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/privilege/user-role-data-grid-view/user-role-data-grid-view.vue'),
                },
                {
                    path: 'userroletypes/:userroletype?/gridview/:gridview?',
                    meta: {
                        caption: 'userroletype.views.gridview.caption',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'userroletypes', parameterName: 'userroletype' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/privilege/user-role-type-grid-view/user-role-type-grid-view.vue'),
                },
                {
                    path: 'systems/:system?/pickupview/:pickupview?',
                    meta: {
                        caption: 'system.views.pickupview.caption',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'systems', parameterName: 'system' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/privilege/system-pickup-view/system-pickup-view.vue'),
                },
                {
                    path: 'users/:user?/editview3/:editview3?',
                    meta: {
                        caption: 'user.views.editview3.caption',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'users', parameterName: 'user' },
                            { pathName: 'editview3', parameterName: 'editview3' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/org/user-edit-view3/user-edit-view3.vue'),
                },
                {
                    path: 'orgdepts/:orgdept?/pickupview/:pickupview?',
                    meta: {
                        caption: 'orgdept.views.pickupview.caption',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'orgdepts', parameterName: 'orgdept' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/org/org-dept-pickup-view/org-dept-pickup-view.vue'),
                },
                {
                    path: 'userobjects/:userobject?/mpickupview/:mpickupview?',
                    meta: {
                        caption: 'userobject.views.mpickupview.caption',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'userobjects', parameterName: 'userobject' },
                            { pathName: 'mpickupview', parameterName: 'mpickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/privilege/user-object-mpickup-view/user-object-mpickup-view.vue'),
                },
                {
                    path: 'orgusers/:orguser?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'orguser.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'orgusers', parameterName: 'orguser' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/org/org-user-pickup-grid-view/org-user-pickup-grid-view.vue'),
                },
                {
                    path: 'userobjects/:userobject?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'userobject.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'userobjects', parameterName: 'userobject' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/privilege/user-object-pickup-grid-view/user-object-pickup-grid-view.vue'),
                },
                {
                    path: 'userroles/:userrole?/gridview/:gridview?',
                    meta: {
                        caption: 'userrole.views.gridview.caption',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'userroles', parameterName: 'userrole' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/privilege/user-role-grid-view/user-role-grid-view.vue'),
                },
                {
                    path: 'users/:user?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'user.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'users', parameterName: 'user' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/org/user-pickup-grid-view/user-pickup-grid-view.vue'),
                },
                {
                    path: 'users/:user?/loginaccounts/:loginaccount?/editview/:editview?',
                    meta: {
                        caption: 'loginaccount.views.editview.caption',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'users', parameterName: 'user' },
                            { pathName: 'loginaccounts', parameterName: 'loginaccount' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/org/login-account-edit-view/login-account-edit-view.vue'),
                },
                {
                    path: 'loginaccounts/:loginaccount?/editview/:editview?',
                    meta: {
                        caption: 'loginaccount.views.editview.caption',
                        parameters: [
                            { pathName: 'index', parameterName: 'index' },
                            { pathName: 'loginaccounts', parameterName: 'loginaccount' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/org/login-account-edit-view/login-account-edit-view.vue'),
                },
            {
                path: 'userroledataredirectview/:userroledataredirectview?',
                meta: {
                    caption: 'userroledata.views.redirectview.caption',
                    parameters: [
                        { pathName: 'userroledataredirectview', parameterName: 'userroledataredirectview' },
                    ],
                    requireAuth: true,
                },
                component: () => import('@pages/privilege/user-role-data-redirect-view/user-role-data-redirect-view.vue'),
            },
            {
                path: 'usergroupdetailredirectview/:usergroupdetailredirectview?',
                meta: {
                    caption: 'usergroupdetail.views.redirectview.caption',
                    parameters: [
                        { pathName: 'usergroupdetailredirectview', parameterName: 'usergroupdetailredirectview' },
                    ],
                    requireAuth: true,
                },
                component: () => import('@pages/privilege/user-group-detail-redirect-view/user-group-detail-redirect-view.vue'),
            },
            {
                path: 'systemredirectview/:systemredirectview?',
                meta: {
                    caption: 'system.views.redirectview.caption',
                    parameters: [
                        { pathName: 'systemredirectview', parameterName: 'systemredirectview' },
                    ],
                    requireAuth: true,
                },
                component: () => import('@pages/privilege/system-redirect-view/system-redirect-view.vue'),
            },
            {
                path: 'userroletyperedirectview/:userroletyperedirectview?',
                meta: {
                    caption: 'userroletype.views.redirectview.caption',
                    parameters: [
                        { pathName: 'userroletyperedirectview', parameterName: 'userroletyperedirectview' },
                    ],
                    requireAuth: true,
                },
                component: () => import('@pages/privilege/user-role-type-redirect-view/user-role-type-redirect-view.vue'),
            },
            {
                path: 'userobjectredirectview/:userobjectredirectview?',
                meta: {
                    caption: 'userobject.views.redirectview.caption',
                    parameters: [
                        { pathName: 'userobjectredirectview', parameterName: 'userobjectredirectview' },
                    ],
                    requireAuth: true,
                },
                component: () => import('@pages/privilege/user-object-redirect-view/user-object-redirect-view.vue'),
            },
            {
                path: 'userroleresredirectview/:userroleresredirectview?',
                meta: {
                    caption: 'userroleres.views.redirectview.caption',
                    parameters: [
                        { pathName: 'userroleresredirectview', parameterName: 'userroleresredirectview' },
                    ],
                    requireAuth: true,
                },
                component: () => import('@pages/privilege/user-role-res-redirect-view/user-role-res-redirect-view.vue'),
            },
            {
                path: 'userroledetailredirectview/:userroledetailredirectview?',
                meta: {
                    caption: 'userroledetail.views.redirectview.caption',
                    parameters: [
                        { pathName: 'userroledetailredirectview', parameterName: 'userroledetailredirectview' },
                    ],
                    requireAuth: true,
                },
                component: () => import('@pages/privilege/user-role-detail-redirect-view/user-role-detail-redirect-view.vue'),
            },
            {
                path: 'applicationredirectview/:applicationredirectview?',
                meta: {
                    caption: 'application.views.redirectview.caption',
                    parameters: [
                        { pathName: 'applicationredirectview', parameterName: 'applicationredirectview' },
                    ],
                    requireAuth: true,
                },
                component: () => import('@pages/privilege/application-redirect-view/application-redirect-view.vue'),
            },
            {
                path: 'userroleredirectview/:userroleredirectview?',
                meta: {
                    caption: 'userrole.views.redirectview.caption',
                    parameters: [
                        { pathName: 'userroleredirectview', parameterName: 'userroleredirectview' },
                    ],
                    requireAuth: true,
                },
                component: () => import('@pages/privilege/user-role-redirect-view/user-role-redirect-view.vue'),
            },
            {
                path: 'uniresredirectview/:uniresredirectview?',
                meta: {
                    caption: 'unires.views.redirectview.caption',
                    parameters: [
                        { pathName: 'uniresredirectview', parameterName: 'uniresredirectview' },
                    ],
                    requireAuth: true,
                },
                component: () => import('@pages/privilege/uni-res-redirect-view/uni-res-redirect-view.vue'),
            },
            {
                path: 'dataentityredirectview/:dataentityredirectview?',
                meta: {
                    caption: 'dataentity.views.redirectview.caption',
                    parameters: [
                        { pathName: 'dataentityredirectview', parameterName: 'dataentityredirectview' },
                    ],
                    requireAuth: true,
                },
                component: () => import('@pages/privilege/data-entity-redirect-view/data-entity-redirect-view.vue'),
            },
            {
                path: 'usergroupredirectview/:usergroupredirectview?',
                meta: {
                    caption: 'usergroup.views.redirectview.caption',
                    parameters: [
                        { pathName: 'usergroupredirectview', parameterName: 'usergroupredirectview' },
                    ],
                    requireAuth: true,
                },
                component: () => import('@pages/privilege/user-group-redirect-view/user-group-redirect-view.vue'),
            },
            ],
        },
    {
        path: '/orgusers/:orguser?/editview3/:editview3?',
        meta: {
            caption: 'orguser.views.editview3.caption',
            parameters: [
                { pathName: 'orgusers', parameterName: 'orguser' },
                { pathName: 'editview3', parameterName: 'editview3' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/org/org-user-edit-view3/org-user-edit-view3.vue'),
    },
    {
        path: '/users/:user?/editview/:editview?',
        meta: {
            caption: 'user.views.editview.caption',
            parameters: [
                { pathName: 'users', parameterName: 'user' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/org/user-edit-view/user-edit-view.vue'),
    },
    {
        path: '/users/:user?/loginaccounts/:loginaccount?/gridview/:gridview?',
        meta: {
            caption: 'loginaccount.views.gridview.caption',
            parameters: [
                { pathName: 'users', parameterName: 'user' },
                { pathName: 'loginaccounts', parameterName: 'loginaccount' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/org/login-account-grid-view/login-account-grid-view.vue'),
    },
    {
        path: '/loginaccounts/:loginaccount?/gridview/:gridview?',
        meta: {
            caption: 'loginaccount.views.gridview.caption',
            parameters: [
                { pathName: 'loginaccounts', parameterName: 'loginaccount' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/org/login-account-grid-view/login-account-grid-view.vue'),
    },
    {
        path: '/orgdeptusers/:orgdeptuser?/editview/:editview?',
        meta: {
            caption: 'orgdeptuser.views.editview.caption',
            parameters: [
                { pathName: 'orgdeptusers', parameterName: 'orgdeptuser' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/org/org-dept-user-edit-view/org-dept-user-edit-view.vue'),
    },
    {
        path: '/orgdepts/:orgdept?/editview/:editview?',
        meta: {
            caption: 'orgdept.views.editview.caption',
            parameters: [
                { pathName: 'orgdepts', parameterName: 'orgdept' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/org/org-dept-edit-view/org-dept-edit-view.vue'),
    },
    {
        path: '/users/:user?/pickupview/:pickupview?',
        meta: {
            caption: 'user.views.pickupview.caption',
            parameters: [
                { pathName: 'users', parameterName: 'user' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/org/user-pickup-view/user-pickup-view.vue'),
    },
    {
        path: '/orgusers/:orguser?/gridview/:gridview?',
        meta: {
            caption: 'orguser.views.gridview.caption',
            parameters: [
                { pathName: 'orgusers', parameterName: 'orguser' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/org/org-user-grid-view/org-user-grid-view.vue'),
    },
    {
        path: '/orgdepts/:orgdept?/pickupview/:pickupview?',
        meta: {
            caption: 'orgdept.views.pickupview.caption',
            parameters: [
                { pathName: 'orgdepts', parameterName: 'orgdept' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/org/org-dept-pickup-view/org-dept-pickup-view.vue'),
    },
    {
        path: '/orgdepts/:orgdept?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'orgdept.views.pickupgridview.caption',
            parameters: [
                { pathName: 'orgdepts', parameterName: 'orgdept' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/org/org-dept-pickup-grid-view/org-dept-pickup-grid-view.vue'),
    },
    {
        path: '/users/:user?/editview3/:editview3?',
        meta: {
            caption: 'user.views.editview3.caption',
            parameters: [
                { pathName: 'users', parameterName: 'user' },
                { pathName: 'editview3', parameterName: 'editview3' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/org/user-edit-view3/user-edit-view3.vue'),
    },
    {
        path: '/orgdepts/:orgdept?/gridview/:gridview?',
        meta: {
            caption: 'orgdept.views.gridview.caption',
            parameters: [
                { pathName: 'orgdepts', parameterName: 'orgdept' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/org/org-dept-grid-view/org-dept-grid-view.vue'),
    },
    {
        path: '/orgs/:org?/pickupview/:pickupview?',
        meta: {
            caption: 'org.views.pickupview.caption',
            parameters: [
                { pathName: 'orgs', parameterName: 'org' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/org/org-pickup-view/org-pickup-view.vue'),
    },
    {
        path: '/orgusers/:orguser?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'orguser.views.pickupgridview.caption',
            parameters: [
                { pathName: 'orgusers', parameterName: 'orguser' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/org/org-user-pickup-grid-view/org-user-pickup-grid-view.vue'),
    },
    {
        path: '/orgs/:org?/gridview/:gridview?',
        meta: {
            caption: 'org.views.gridview.caption',
            parameters: [
                { pathName: 'orgs', parameterName: 'org' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/org/org-grid-view/org-grid-view.vue'),
    },
    {
        path: '/orgdeptusers/:orgdeptuser?/gridview/:gridview?',
        meta: {
            caption: 'orgdeptuser.views.gridview.caption',
            parameters: [
                { pathName: 'orgdeptusers', parameterName: 'orgdeptuser' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/org/org-dept-user-grid-view/org-dept-user-grid-view.vue'),
    },
    {
        path: '/orgs/:org?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'org.views.pickupgridview.caption',
            parameters: [
                { pathName: 'orgs', parameterName: 'org' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/org/org-pickup-grid-view/org-pickup-grid-view.vue'),
    },
    {
        path: '/orgs/:org?/editview/:editview?',
        meta: {
            caption: 'org.views.editview.caption',
            parameters: [
                { pathName: 'orgs', parameterName: 'org' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/org/org-edit-view/org-edit-view.vue'),
    },
    {
        path: '/users/:user?/loginaccounts/:loginaccount?/editview/:editview?',
        meta: {
            caption: 'loginaccount.views.editview.caption',
            parameters: [
                { pathName: 'users', parameterName: 'user' },
                { pathName: 'loginaccounts', parameterName: 'loginaccount' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/org/login-account-edit-view/login-account-edit-view.vue'),
    },
    {
        path: '/loginaccounts/:loginaccount?/editview/:editview?',
        meta: {
            caption: 'loginaccount.views.editview.caption',
            parameters: [
                { pathName: 'loginaccounts', parameterName: 'loginaccount' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/org/login-account-edit-view/login-account-edit-view.vue'),
    },
    {
        path: '/users/:user?/gridview/:gridview?',
        meta: {
            caption: 'user.views.gridview.caption',
            parameters: [
                { pathName: 'users', parameterName: 'user' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/org/user-grid-view/user-grid-view.vue'),
    },
    {
        path: '/users/:user?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'user.views.pickupgridview.caption',
            parameters: [
                { pathName: 'users', parameterName: 'user' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/org/user-pickup-grid-view/user-pickup-grid-view.vue'),
    },
    {
        path: '/orgusers/:orguser?/pickupview/:pickupview?',
        meta: {
            caption: 'orguser.views.pickupview.caption',
            parameters: [
                { pathName: 'orgusers', parameterName: 'orguser' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/org/org-user-pickup-view/org-user-pickup-view.vue'),
    },
    {
        path: '/usergroups/:usergroup?/gridview/:gridview?',
        meta: {
            caption: 'usergroup.views.gridview.caption',
            parameters: [
                { pathName: 'usergroups', parameterName: 'usergroup' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/privilege/user-group-grid-view/user-group-grid-view.vue'),
    },
    {
        path: '/userroles/:userrole?/pickupview/:pickupview?',
        meta: {
            caption: 'userrole.views.pickupview.caption',
            parameters: [
                { pathName: 'userroles', parameterName: 'userrole' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/privilege/user-role-pickup-view/user-role-pickup-view.vue'),
    },
    {
        path: '/unires/:unires?/mpickupview/:mpickupview?',
        meta: {
            caption: 'unires.views.mpickupview.caption',
            parameters: [
                { pathName: 'unires', parameterName: 'unires' },
                { pathName: 'mpickupview', parameterName: 'mpickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/privilege/uni-res-mpickup-view/uni-res-mpickup-view.vue'),
    },
    {
        path: '/usergroups/:usergroup?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'usergroup.views.pickupgridview.caption',
            parameters: [
                { pathName: 'usergroups', parameterName: 'usergroup' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/privilege/user-group-pickup-grid-view/user-group-pickup-grid-view.vue'),
    },
    {
        path: '/systems/:system?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'system.views.pickupgridview.caption',
            parameters: [
                { pathName: 'systems', parameterName: 'system' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/privilege/system-pickup-grid-view/system-pickup-grid-view.vue'),
    },
    {
        path: '/userroletypes/:userroletype?/gridview/:gridview?',
        meta: {
            caption: 'userroletype.views.gridview.caption',
            parameters: [
                { pathName: 'userroletypes', parameterName: 'userroletype' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/privilege/user-role-type-grid-view/user-role-type-grid-view.vue'),
    },
    {
        path: '/unires/:unires?/editview/:editview?',
        meta: {
            caption: 'unires.views.editview.caption',
            parameters: [
                { pathName: 'unires', parameterName: 'unires' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/privilege/uni-res-edit-view/uni-res-edit-view.vue'),
    },
    {
        path: '/userobjects/:userobject?/mpickupview/:mpickupview?',
        meta: {
            caption: 'userobject.views.mpickupview.caption',
            parameters: [
                { pathName: 'userobjects', parameterName: 'userobject' },
                { pathName: 'mpickupview', parameterName: 'mpickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/privilege/user-object-mpickup-view/user-object-mpickup-view.vue'),
    },
    {
        path: '/userroledata/:userroledata?/mpickupview/:mpickupview?',
        meta: {
            caption: 'userroledata.views.mpickupview.caption',
            parameters: [
                { pathName: 'userroledata', parameterName: 'userroledata' },
                { pathName: 'mpickupview', parameterName: 'mpickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/privilege/user-role-data-mpickup-view/user-role-data-mpickup-view.vue'),
    },
    {
        path: '/usergroupdetails/:usergroupdetail?/editview/:editview?',
        meta: {
            caption: 'usergroupdetail.views.editview.caption',
            parameters: [
                { pathName: 'usergroupdetails', parameterName: 'usergroupdetail' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/privilege/user-group-detail-edit-view/user-group-detail-edit-view.vue'),
    },
    {
        path: '/userroles/:userrole?/usrcreateeditview3/:usrcreateeditview3?',
        meta: {
            caption: 'userrole.views.usrcreateeditview3.caption',
            parameters: [
                { pathName: 'userroles', parameterName: 'userrole' },
                { pathName: 'usrcreateeditview3', parameterName: 'usrcreateeditview3' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/privilege/user-role-usr-create-edit-view3/user-role-usr-create-edit-view3.vue'),
    },
    {
        path: '/userroledetails/:userroledetail?/editview/:editview?',
        meta: {
            caption: 'userroledetail.views.editview.caption',
            parameters: [
                { pathName: 'userroledetails', parameterName: 'userroledetail' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/privilege/user-role-detail-edit-view/user-role-detail-edit-view.vue'),
    },
    {
        path: '/userroleres/:userroleres?/editview/:editview?',
        meta: {
            caption: 'userroleres.views.editview.caption',
            parameters: [
                { pathName: 'userroleres', parameterName: 'userroleres' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/privilege/user-role-res-edit-view/user-role-res-edit-view.vue'),
    },
    {
        path: '/userroledata/:userroledata?/pickupview/:pickupview?',
        meta: {
            caption: 'userroledata.views.pickupview.caption',
            parameters: [
                { pathName: 'userroledata', parameterName: 'userroledata' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/privilege/user-role-data-pickup-view/user-role-data-pickup-view.vue'),
    },
    {
        path: '/usergroups/:usergroup?/editview3/:editview3?',
        meta: {
            caption: 'usergroup.views.editview3.caption',
            parameters: [
                { pathName: 'usergroups', parameterName: 'usergroup' },
                { pathName: 'editview3', parameterName: 'editview3' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/privilege/user-group-edit-view3/user-group-edit-view3.vue'),
    },
    {
        path: '/userobjects/:userobject?/gridview/:gridview?',
        meta: {
            caption: 'userobject.views.gridview.caption',
            parameters: [
                { pathName: 'userobjects', parameterName: 'userobject' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/privilege/user-object-grid-view/user-object-grid-view.vue'),
    },
    {
        path: '/userroletypes/:userroletype?/editview/:editview?',
        meta: {
            caption: 'userroletype.views.editview.caption',
            parameters: [
                { pathName: 'userroletypes', parameterName: 'userroletype' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/privilege/user-role-type-edit-view/user-role-type-edit-view.vue'),
    },
    {
        path: '/unires/:unires?/gridview/:gridview?',
        meta: {
            caption: 'unires.views.gridview.caption',
            parameters: [
                { pathName: 'unires', parameterName: 'unires' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/privilege/uni-res-grid-view/uni-res-grid-view.vue'),
    },
    {
        path: '/userobjects/:userobject?/editview/:editview?',
        meta: {
            caption: 'userobject.views.editview.caption',
            parameters: [
                { pathName: 'userobjects', parameterName: 'userobject' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/privilege/user-object-edit-view/user-object-edit-view.vue'),
    },
    {
        path: '/systems/:system?/pickupview/:pickupview?',
        meta: {
            caption: 'system.views.pickupview.caption',
            parameters: [
                { pathName: 'systems', parameterName: 'system' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/privilege/system-pickup-view/system-pickup-view.vue'),
    },
    {
        path: '/usergroupdetails/:usergroupdetail?/gridview/:gridview?',
        meta: {
            caption: 'usergroupdetail.views.gridview.caption',
            parameters: [
                { pathName: 'usergroupdetails', parameterName: 'usergroupdetail' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/privilege/user-group-detail-grid-view/user-group-detail-grid-view.vue'),
    },
    {
        path: '/systems/:system?/editview/:editview?',
        meta: {
            caption: 'system.views.editview.caption',
            parameters: [
                { pathName: 'systems', parameterName: 'system' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/privilege/system-edit-view/system-edit-view.vue'),
    },
    {
        path: '/userroles/:userrole?/editview3/:editview3?',
        meta: {
            caption: 'userrole.views.editview3.caption',
            parameters: [
                { pathName: 'userroles', parameterName: 'userrole' },
                { pathName: 'editview3', parameterName: 'editview3' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/privilege/user-role-edit-view3/user-role-edit-view3.vue'),
    },
    {
        path: '/userroles/:userrole?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'userrole.views.pickupgridview.caption',
            parameters: [
                { pathName: 'userroles', parameterName: 'userrole' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/privilege/user-role-pickup-grid-view/user-role-pickup-grid-view.vue'),
    },
    {
        path: '/unires/:unires?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'unires.views.pickupgridview.caption',
            parameters: [
                { pathName: 'unires', parameterName: 'unires' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/privilege/uni-res-pickup-grid-view/uni-res-pickup-grid-view.vue'),
    },
    {
        path: '/userroledata/:userroledata?/gridview/:gridview?',
        meta: {
            caption: 'userroledata.views.gridview.caption',
            parameters: [
                { pathName: 'userroledata', parameterName: 'userroledata' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/privilege/user-role-data-grid-view/user-role-data-grid-view.vue'),
    },
    {
        path: '/applications/:application?/gridview/:gridview?',
        meta: {
            caption: 'application.views.gridview.caption',
            parameters: [
                { pathName: 'applications', parameterName: 'application' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/privilege/application-grid-view/application-grid-view.vue'),
    },
    {
        path: '/unires/:unires?/pickupview/:pickupview?',
        meta: {
            caption: 'unires.views.pickupview.caption',
            parameters: [
                { pathName: 'unires', parameterName: 'unires' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/privilege/uni-res-pickup-view/uni-res-pickup-view.vue'),
    },
    {
        path: '/userroledetails/:userroledetail?/gridview/:gridview?',
        meta: {
            caption: 'userroledetail.views.gridview.caption',
            parameters: [
                { pathName: 'userroledetails', parameterName: 'userroledetail' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/privilege/user-role-detail-grid-view/user-role-detail-grid-view.vue'),
    },
    {
        path: '/userroleres/:userroleres?/gridview/:gridview?',
        meta: {
            caption: 'userroleres.views.gridview.caption',
            parameters: [
                { pathName: 'userroleres', parameterName: 'userroleres' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/privilege/user-role-res-grid-view/user-role-res-grid-view.vue'),
    },
    {
        path: '/dataentities/:dataentity?/gridview/:gridview?',
        meta: {
            caption: 'dataentity.views.gridview.caption',
            parameters: [
                { pathName: 'dataentities', parameterName: 'dataentity' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/privilege/data-entity-grid-view/data-entity-grid-view.vue'),
    },
    {
        path: '/applications/:application?/editview/:editview?',
        meta: {
            caption: 'application.views.editview.caption',
            parameters: [
                { pathName: 'applications', parameterName: 'application' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/privilege/application-edit-view/application-edit-view.vue'),
    },
    {
        path: '/userroledatas/:userroledatas?/gridview/:gridview?',
        meta: {
            caption: 'userroledatas.views.gridview.caption',
            parameters: [
                { pathName: 'userroledatas', parameterName: 'userroledatas' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/privilege/userroledatasgrid-view/userroledatasgrid-view.vue'),
    },
    {
        path: '/userroles/:userrole?/mpickupview/:mpickupview?',
        meta: {
            caption: 'userrole.views.mpickupview.caption',
            parameters: [
                { pathName: 'userroles', parameterName: 'userrole' },
                { pathName: 'mpickupview', parameterName: 'mpickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/privilege/user-role-mpickup-view/user-role-mpickup-view.vue'),
    },
    {
        path: '/dataentities/:dataentity?/pickupview/:pickupview?',
        meta: {
            caption: 'dataentity.views.pickupview.caption',
            parameters: [
                { pathName: 'dataentities', parameterName: 'dataentity' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/privilege/data-entity-pickup-view/data-entity-pickup-view.vue'),
    },
    {
        path: '/usergroups/:usergroup?/mpickupview/:mpickupview?',
        meta: {
            caption: 'usergroup.views.mpickupview.caption',
            parameters: [
                { pathName: 'usergroups', parameterName: 'usergroup' },
                { pathName: 'mpickupview', parameterName: 'mpickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/privilege/user-group-mpickup-view/user-group-mpickup-view.vue'),
    },
    {
        path: '/dataentities/:dataentity?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'dataentity.views.pickupgridview.caption',
            parameters: [
                { pathName: 'dataentities', parameterName: 'dataentity' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/privilege/data-entity-pickup-grid-view/data-entity-pickup-grid-view.vue'),
    },
    {
        path: '/userroledataactions/:userroledataaction?/gridview/:gridview?',
        meta: {
            caption: 'userroledataaction.views.gridview.caption',
            parameters: [
                { pathName: 'userroledataactions', parameterName: 'userroledataaction' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/privilege/user-role-data-action-grid-view/user-role-data-action-grid-view.vue'),
    },
    {
        path: '/userobjects/:userobject?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'userobject.views.pickupgridview.caption',
            parameters: [
                { pathName: 'userobjects', parameterName: 'userobject' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/privilege/user-object-pickup-grid-view/user-object-pickup-grid-view.vue'),
    },
    {
        path: '/userroledataactions/:userroledataaction?/editview/:editview?',
        meta: {
            caption: 'userroledataaction.views.editview.caption',
            parameters: [
                { pathName: 'userroledataactions', parameterName: 'userroledataaction' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/privilege/user-role-data-action-edit-view/user-role-data-action-edit-view.vue'),
    },
    {
        path: '/dataentities/:dataentity?/editview/:editview?',
        meta: {
            caption: 'dataentity.views.editview.caption',
            parameters: [
                { pathName: 'dataentities', parameterName: 'dataentity' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/privilege/data-entity-edit-view/data-entity-edit-view.vue'),
    },
    {
        path: '/userroledata/:userroledata?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'userroledata.views.pickupgridview.caption',
            parameters: [
                { pathName: 'userroledata', parameterName: 'userroledata' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/privilege/user-role-data-pickup-grid-view/user-role-data-pickup-grid-view.vue'),
    },
    {
        path: '/userroledata/:userroledata?/editview3/:editview3?',
        meta: {
            caption: 'userroledata.views.editview3.caption',
            parameters: [
                { pathName: 'userroledata', parameterName: 'userroledata' },
                { pathName: 'editview3', parameterName: 'editview3' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/privilege/user-role-data-edit-view3/user-role-data-edit-view3.vue'),
    },
    {
        path: '/userroles/:userrole?/gridview/:gridview?',
        meta: {
            caption: 'userrole.views.gridview.caption',
            parameters: [
                { pathName: 'userroles', parameterName: 'userrole' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/privilege/user-role-grid-view/user-role-grid-view.vue'),
    },
    {
        path: '/userroledatas/:userroledatas?/editview/:editview?',
        meta: {
            caption: 'userroledatas.views.editview.caption',
            parameters: [
                { pathName: 'userroledatas', parameterName: 'userroledatas' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/privilege/userroledatasedit-view/userroledatasedit-view.vue'),
    },
    {
        path: '/usergroups/:usergroup?/editview/:editview?',
        meta: {
            caption: 'usergroup.views.editview.caption',
            parameters: [
                { pathName: 'usergroups', parameterName: 'usergroup' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/privilege/user-group-edit-view/user-group-edit-view.vue'),
    },
    {
        path: '/userobjects/:userobject?/pickupview/:pickupview?',
        meta: {
            caption: 'userobject.views.pickupview.caption',
            parameters: [
                { pathName: 'userobjects', parameterName: 'userobject' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/privilege/user-object-pickup-view/user-object-pickup-view.vue'),
    },
    {
        path: '/systems/:system?/gridview/:gridview?',
        meta: {
            caption: 'system.views.gridview.caption',
            parameters: [
                { pathName: 'systems', parameterName: 'system' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/privilege/system-grid-view/system-grid-view.vue'),
    },
        {
            path: '/login/:login?',
            name: 'login',
            meta: {  
                caption: '登录',
                viewType: 'login',
                requireAuth: false,
                ignoreAddPage: true,
            },
            beforeEnter: (to: any, from: any, next: any) => {
                router.app.$store.commit('resetRootStateData');
                next();
            },
            component: () => import('@components/login/login.vue'),
        },
        {
            path: '/404',
            component: () => import('@components/404/404.vue')
        },
        {
            path: '/500',
            component: () => import('@components/500/500.vue')
        },
        {
            path: '*',
            redirect: 'index'
        },
    ],
});

export default router;
